@@ -8,11 +8,11 @@
  * distribute, sub license, and/or sell copies of the Software, and to
  * permit persons to whom the Software is furnished to do so, subject to
  * the following conditions:
- * 
+ *
  * The above copyright notice and this permission notice (including the
  * next paragraph) shall be included in all copies or substantial portions
  * of the Software.
- * 
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
  * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
  * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT.
@@ -44,45 +44,42 @@
 #define CHECK_SYMBOL(func) { if (!func) printf("func %s not found\n", #func); return VA_STATUS_ERROR_UNKNOWN; }
 #define DEVICE_NAME "/dev/dri/renderD128"
 
-static int open_device (char *dev_name)
+static int open_device(char *dev_name)
 {
     struct stat st;
     int fd;
 
-    if (-1 == stat (dev_name, &st))
-    {
-        printf ("Cannot identify '%s': %d, %s\n",
-                dev_name, errno, strerror (errno));
+    if (-1 == stat(dev_name, &st)) {
+        printf("Cannot identify '%s': %d, %s\n",
+               dev_name, errno, strerror(errno));
         return -1;
     }
 
-    if (!S_ISCHR (st.st_mode))
-    {
-        printf ("%s is no device\n", dev_name);
+    if (!S_ISCHR(st.st_mode)) {
+        printf("%s is no device\n", dev_name);
         return -1;
     }
 
-    fd = open (dev_name, O_RDWR);
+    fd = open(dev_name, O_RDWR);
 
-    if (-1 == fd)
-    {
-        fprintf (stderr, "Cannot open '%s': %d, %s\n",
-                 dev_name, errno, strerror (errno));
+    if (-1 == fd) {
+        fprintf(stderr, "Cannot open '%s': %d, %s\n",
+                dev_name, errno, strerror(errno));
         return -1;
     }
 
     return fd;
 }
 
-static int va_DisplayContextIsValid (
+static int va_DisplayContextIsValid(
     VADisplayContextP pDisplayContext
-                                  )
+)
 {
     return (pDisplayContext != NULL &&
             pDisplayContext->pDriverContext != NULL);
 }
 
-static void va_DisplayContextDestroy (
+static void va_DisplayContextDestroy(
     VADisplayContextP pDisplayContext
 )
 {
@@ -112,14 +109,14 @@ static VAStatus va_DisplayContextGetNumCandidates(
     drm_state->fd = open_device((char *)DEVICE_NAME);
 
     if (drm_state->fd < 0) {
-        fprintf(stderr,"can't open DRM devices\n");
+        fprintf(stderr, "can't open DRM devices\n");
         return VA_STATUS_ERROR_UNKNOWN;
     }
     drm_state->auth_type = VA_DRM_AUTH_CUSTOM;
     return VA_DRM_GetNumCandidates(ctx, num_candidates);
 }
 
-static VAStatus va_DisplayContextGetDriverNameByIndex (
+static VAStatus va_DisplayContextGetDriverNameByIndex(
     VADisplayContextP pDisplayContext,
     char **driver_name,
     int candidate_index
@@ -131,7 +128,7 @@ static VAStatus va_DisplayContextGetDriverNameByIndex (
 }
 
 
-VADisplay vaGetDisplay (
+VADisplay vaGetDisplay(
     void *native_dpy /* implementation specific */
 )
 {
