@@ -8,11 +8,11 @@
  * distribute, sub license, and/or sell copies of the Software, and to
  * permit persons to whom the Software is furnished to do so, subject to
  * the following conditions:
- * 
+ *
  * The above copyright notice and this permission notice (including the
  * next paragraph) shall be included in all copies or substantial portions
  * of the Software.
- * 
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
  * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
  * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT.
@@ -55,18 +55,19 @@ static const struct driver_name_map g_dri2_driver_name_map[] = {
     { "i965",       4, "i965"   }, // Intel i965 VAAPI driver with i965 DRI driver
     { "iris",       4, "iHD"    }, // Intel iHD  VAAPI driver with iris DRI driver
     { "iris",       4, "i965"   }, // Intel i965 VAAPI driver with iris DRI driver
+    { "crocus",     6, "i965"   }, // Intel i965 VAAPI driver with crocus DRI driver
     { NULL,         0, NULL }
 };
 
-static int va_DisplayContextIsValid (
+static int va_DisplayContextIsValid(
     VADisplayContextP pDisplayContext
 )
 {
-    return (pDisplayContext != NULL && 
+    return (pDisplayContext != NULL &&
             pDisplayContext->pDriverContext != NULL);
 }
 
-static void va_DisplayContextDestroy (
+static void va_DisplayContextDestroy(
     VADisplayContextP pDisplayContext
 )
 {
@@ -87,7 +88,7 @@ static void va_DisplayContextDestroy (
     free(pDisplayContext);
 }
 
-static VAStatus va_DRI2_GetNumCandidates (
+static VAStatus va_DRI2_GetNumCandidates(
     VADisplayContextP pDisplayContext,
     int *num_candidates
 )
@@ -120,7 +121,7 @@ static VAStatus va_DRI2_GetNumCandidates (
     return VA_STATUS_SUCCESS;
 }
 
-static VAStatus va_DRI2_GetDriverName (
+static VAStatus va_DRI2_GetDriverName(
     VADisplayContextP pDisplayContext,
     char **driver_name_ptr,
     int candidate_index
@@ -161,7 +162,7 @@ static VAStatus va_DRI2_GetDriverName (
     return VA_STATUS_SUCCESS;
 }
 
-static VAStatus va_NVCTRL_GetDriverName (
+static VAStatus va_NVCTRL_GetDriverName(
     VADisplayContextP pDisplayContext,
     char **driver_name,
     int candidate_index
@@ -175,7 +176,7 @@ static VAStatus va_NVCTRL_GetDriverName (
         return VA_STATUS_ERROR_INVALID_PARAMETER;
 
     result = VA_NVCTRLQueryDirectRenderingCapable(ctx->native_dpy, ctx->x11_screen,
-                                                  &direct_capable);
+             &direct_capable);
     if (!result || !direct_capable)
         return VA_STATUS_ERROR_UNKNOWN;
 
@@ -188,7 +189,7 @@ static VAStatus va_NVCTRL_GetDriverName (
     return VA_STATUS_SUCCESS;
 }
 
-static VAStatus va_FGLRX_GetDriverName (
+static VAStatus va_FGLRX_GetDriverName(
     VADisplayContextP pDisplayContext,
     char **driver_name,
     int candidate_index
@@ -210,7 +211,7 @@ static VAStatus va_FGLRX_GetDriverName (
     return VA_STATUS_SUCCESS;
 }
 
-static VAStatus va_DisplayContextGetDriverName (
+static VAStatus va_DisplayContextGetDriverName(
     VADisplayContextP pDisplayContext,
     char **driver_name, int candidate_index
 )
@@ -231,7 +232,7 @@ static VAStatus va_DisplayContextGetDriverName (
     return vaStatus;
 }
 
-static VAStatus va_DisplayContextGetNumCandidates (
+static VAStatus va_DisplayContextGetNumCandidates(
     VADisplayContextP pDisplayContext,
     int *num_candidates
 )
@@ -245,12 +246,12 @@ static VAStatus va_DisplayContextGetNumCandidates (
      * fallbacks only have 1 candidate driver.
      */
     if (vaStatus != VA_STATUS_SUCCESS)
-      *num_candidates = 1;
+        *num_candidates = 1;
 
     return VA_STATUS_SUCCESS;
 }
 
-VADisplay vaGetDisplay (
+VADisplay vaGetDisplay(
     Display *native_dpy /* implementation specific */
 )
 {
@@ -287,12 +288,15 @@ VADisplay vaGetDisplay (
         return NULL;
     }
 
+    dri_state->base.fd = -1;
+    dri_state->base.auth_type = VA_NONE;
+
     pDriverContext->drm_state = dri_state;
 
     return (VADisplay)pDisplayContext;
 }
 
-void va_TracePutSurface (
+void va_TracePutSurface(
     VADisplay dpy,
     VASurfaceID surface,
     void *draw, /* the target Drawable */
@@ -309,7 +313,7 @@ void va_TracePutSurface (
     unsigned int flags /* de-interlacing flags */
 );
 
-VAStatus vaPutSurface (
+VAStatus vaPutSurface(
     VADisplay dpy,
     VASurfaceID surface,
     Drawable draw, /* X Drawable */
@@ -326,19 +330,19 @@ VAStatus vaPutSurface (
     unsigned int flags /* de-interlacing flags */
 )
 {
-  VADriverContextP ctx;
+    VADriverContextP ctx;
 
-  if (va_fool_postp)
-      return VA_STATUS_SUCCESS;
+    if (va_fool_postp)
+        return VA_STATUS_SUCCESS;
 
-  CHECK_DISPLAY(dpy);
-  ctx = CTX(dpy);
-  
-  VA_TRACE_LOG(va_TracePutSurface, dpy, surface, (void *)draw, srcx, srcy, srcw, srch,
-               destx, desty, destw, desth,
-               cliprects, number_cliprects, flags );
-  
-  return ctx->vtable->vaPutSurface( ctx, surface, (void *)draw, srcx, srcy, srcw, srch,
-                                   destx, desty, destw, desth,
-                                   cliprects, number_cliprects, flags );
+    CHECK_DISPLAY(dpy);
+    ctx = CTX(dpy);
+
+    VA_TRACE_LOG(va_TracePutSurface, dpy, surface, (void *)draw, srcx, srcy, srcw, srch,
+                 destx, desty, destw, desth,
+                 cliprects, number_cliprects, flags);
+
+    return ctx->vtable->vaPutSurface(ctx, surface, (void *)draw, srcx, srcy, srcw, srch,
+                                     destx, desty, destw, desth,
+                                     cliprects, number_cliprects, flags);
 }
